@@ -1,7 +1,7 @@
 from itertools import tee
 from re import compile as compile_re
 
-from flask import _app_ctx_stack, request
+from flask import current_app, request
 
 from flask_minify.cache import MemoryCache
 from flask_minify.parsers import Parser
@@ -112,17 +112,18 @@ class Minify:
 
     @property
     def app(self):
-        """If app was passed take it, if not get the one on top.
+        """If app was passed take it, otherwise fallback to `Flask.current_app`.
 
         Returns
         -------
         Flask App
             The current Flask application.
         """
-        return self._app or (_app_ctx_stack.top and _app_ctx_stack.top.app)
+        return self._app or current_app
 
     def init_app(self, app):
         """Handle initiation of multiple apps NOTE:Factory Method"""
+        self._app = app
         app.after_request(self.main)
         app.teardown_appcontext(self.teardown)
 
